==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_66.js <==
var searchData=
[
  ['f',['f',['../structplplot_1_1__N5.html#a10a493c8a3873541c5631b3699a276e1',1,'plplot::_N5::f()'],['../structplplot_1_1__N6.html#abb808eca634b7eea7801be932a5bcc24',1,'plplot::_N6::f()'],['../structPLfGrid.html#a639c6caea5afe956c4b25a0d83457257',1,'PLfGrid::f()'],['../structPLfGrid2.html#a71f4210cda470d1cfcd396b67a2d16ed',1,'PLfGrid2::f()'],['../structPLfGrid.html#a8240879c6146264e3f5775c37ee27cf7',1,'PLfGrid::f()']]],
  ['f2eval',['f2eval',['../structplf2ops__t.html#a13c5ce017876fcde152ba0e9f28f818e',1,'plf2ops_t']]],
  ['faceted',['FACETED',['../classplplot.html#a18562f076d6241fcb70174c56cc9d0f2',1,'plplot::FACETED()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad9704a54d0cce3496ac15f537f6faa77',1,'plplot.core.plplotjavacConstants.FACETED()'],['../namespaceplplotc.html#a06cb014434e1693c91aafa65d2996c52',1,'plplotc.FACETED()']]],
  ['falsecolor',['falsecolor',['../plot3d_8c.html#a35fc920e3be5be1abe62e62b509c7bf8',1,'plot3d.c']]],
  ['famadv',['famadv',['../structPLStream.html#a15b0c38ac1073ccd572752bbca88642a',1,'PLStream']]],
  ['family',['family',['../structPLStream.html#a45e944722760a5e71145fcdde5de2988',1,'PLStream']]],
  ['familylookup',['familyLookup',['../cairo_8c.html#ac9fb021905982c9f5c5f1213d0a6fa09',1,'cairo.c']]],
  ['fc_5fmaxz',['fc_maxz',['../plot3d_8c.html#af927db7d342d1f8086233de68aef9122',1,'plot3d.c']]],
  ['fc_5fminz',['fc_minz',['../plot3d_8c.html#ab3ab5bb5121a04bc6d319c8e5d344d0a',1,'plot3d.c']]],
  ['fci',['fci',['../classwxPLDevBase.html#a7aeccbdbe73e43b6e1804a9caa8f4baa',1,'wxPLDevBase::fci()'],['../structFCI__to__FontName__Table.html#a10edb24d1c032ee66f3de1be72ce0aa0',1,'FCI_to_FontName_Table::fci()'],['../structPLStream.html#ad5b9970ff24d3eadc87e039312e1e498',1,'PLStream::fci()']]],
  ['fcncoordtrans',['fcnCoordTrans',['../plplot__octaveOCTAVE__wrap_8cxx.html#a155f6008b033b8b13bc7ead36da93c6e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['fcnlabelfunc',['fcnLabelFunc',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9dc9722fd122f685f600c847d96992d4',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['fcnmapform',['fcnMapForm',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab35fb75236326f44a50a302d85f5f72c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['fd',['fd',['../structPLiodev.html#a1ecf4e38fea001587e942564372e1196',1,'PLiodev']]],
  ['fdata',['fdata',['../structtclMatrix.html#a4f4d6a7288dc4f8972e0f708b5eac2ee',1,'tclMatrix']]],
  ['fflen',['fflen',['../structPLStream.html#aa7440a327d3574823524dd545fd47281',1,'PLStream']]],
  ['fgcolor',['fgcolor',['../structTkwDisplay.html#af3d31f2906890adc100c5ada119560e4',1,'TkwDisplay::fgcolor()'],['../structXwDisplay.html#a88fee844ac89cb7046fb8a1dbd79b8a5',1,'XwDisplay::fgcolor()']]],
  ['file',['file',['../structPDFstrm.html#a736196e61b0cdeb3463a200dc39efae6',1,'PDFstrm::file()'],['../structPLiodev.html#a29d807a9caf26fb58320dcc4598e7174',1,'PLiodev::file()']]],
  ['filehandle',['fileHandle',['../structPLiodev.html#a39d8e71193ac0bdf062a381fb945891b',1,'PLiodev']]],
  ['filename',['fileName',['../structPLiodev.html#a3ad87e4e8c43f6d0c9b5d4b3350274ef',1,'PLiodev::fileName()'],['../structPLStream.html#a851b40b7643756cf9e7c998101bf3dfc',1,'PLStream::FileName()'],['../tkMain_8c.html#a1862cb72b37ffe98140c1fcf06a28969',1,'fileName():&#160;tkMain.c']]],
  ['filew',['filew',['../structGcwPLdev.html#a5ff815e8e92376119600093ffd6bdc08',1,'GcwPLdev']]],
  ['fill',['fill',['../structarc__struct.html#afe157be1d680aa7664b402c7591648e3',1,'arc_struct']]],
  ['fill_5fcolor',['fill_color',['../struct__PlplotCanvasHacktext.html#a069d2955ab4655c20978a32e453f139f',1,'_PlplotCanvasHacktext']]],
  ['fill_5fpixel',['fill_pixel',['../struct__PlplotCanvasHacktext.html#aca6cad78a318081c75361890dd3141bc',1,'_PlplotCanvasHacktext']]],
  ['fill_5frgba',['fill_rgba',['../struct__PlplotCanvasHacktext.html#a42583d4c9a7dcef3b03d2dd3e7b5cd2d',1,'_PlplotCanvasHacktext']]],
  ['fill_5fset',['fill_set',['../struct__PlplotCanvasHacktext.html#a402e21892d15b29de7278bce0bb0db30',1,'_PlplotCanvasHacktext']]],
  ['finc',['finc',['../structPLStream.html#a052c6ef447de417a9670e6ee0dbfdd57',1,'PLStream']]],
  ['first_5fid',['first_id',['../structdelaunay.html#a9e2372eabc17ab9883c5cf1fdc9698fd',1,'delaunay']]],
  ['flags',['flags',['../structdelaunay.html#af01616b85855dda0358e7f7db76aab4a',1,'delaunay::flags()'],['../structPlFrame.html#ac7d94201e4d78f789f1a70a8c23974e7',1,'PlFrame::flags()'],['../structPlPlotter.html#ad646104e671c52179ff2e95097f86b22',1,'PlPlotter::flags()'],['../structTkwDev.html#a674aac7197570ce479b71cafc94e5fc7',1,'TkwDev::flags()'],['../structswig__octave__member.html#ac4ef5a8526e5efe3966b6cad209b3271',1,'swig_octave_member::flags()']]],
  ['fntbffr',['fntbffr',['../plsym_8c.html#af2b4286fc1004e0b6909e9618ec32728',1,'plsym.c']]],
  ['fntindx',['fntindx',['../plsym_8c.html#a3c4021b9f3a74ea606a02e08e07e976c',1,'plsym.c']]],
  ['fntlkup',['fntlkup',['../plsym_8c.html#a14403991913eddd3ba18b2144c412684',1,'plsym.c']]],
  ['font',['font',['../struct__PlplotCanvasHacktextPriv.html#a4cf9b7145cc251a6fbf0a9ba5a0b706c',1,'_PlplotCanvasHacktextPriv::font()'],['../structHershey__to__Unicode__table.html#a521461503b5769550a4fa14a9920312b',1,'Hershey_to_Unicode_table::Font()']]],
  ['font_5fface',['font_face',['../structEscText.html#acf964bbf4e977b425f33a26da0e1c9c8',1,'EscText']]],
  ['font_5ftypes',['font_types',['../plsym_8c.html#a76b3973fc2f1b1e8214f93bebb3ca837',1,'plsym.c']]],
  ['fontfamilylookup',['fontFamilyLookup',['../wxwidgets_8h.html#a98e63d912a13da0ed2a2568547e55479',1,'wxwidgets.h']]],
  ['fontlist',['fontlist',['../structcdImageStruct.html#aa1f1595229c3fae8971b0f83d38b08b3',1,'cdImageStruct']]],
  ['fontloaded',['fontloaded',['../plsym_8c.html#aaffc055192a40b2b7bda72fff0aba9f6',1,'plsym.c']]],
  ['fontscale',['fontScale',['../classwxPLDevBase.html#aed1c6ee03a9388f72b05d2b82e049b74',1,'wxPLDevBase']]],
  ['fontsize',['fontSize',['../structPLCairo.html#a1bd9c88d9f2013801eabf81685c2022e',1,'PLCairo::fontSize()'],['../classwxPLDevBase.html#a444c06e289e3873c397b35c6b1ee19db',1,'wxPLDevBase::fontSize()']]],
  ['fontstylelookup',['fontStyleLookup',['../wxwidgets_8h.html#a9527465bcb32eac9a8b9d7f58567e825',1,'wxwidgets.h']]],
  ['fontweightlookup',['fontWeightLookup',['../wxwidgets_8h.html#a9f01825db2b4a454b7c875fe6cd7c385',1,'wxwidgets.h']]],
  ['foo',['foo',['../plcore_8c.html#a819b717d29c6c488a332fefeeb3815ba',1,'foo():&#160;plcore.c'],['../plgradient_8c.html#a819b717d29c6c488a332fefeeb3815ba',1,'foo():&#160;plgradient.c']]],
  ['fp',['fp',['../structPSDev.html#a2218cf8dd6d7fb30f735073048438253',1,'PSDev']]],
  ['framearray',['FrameArray',['../classwxPLplotApp.html#a7bd70e752d99bb4bcfdce9a9c33798b8',1,'wxPLplotApp']]],
  ['free2dgrid',['Free2dGrid',['../classplplot.html#a284542add18e412b4f9f6b071dc6a9b3',1,'plplot']]],
  ['freeaspect',['freeaspect',['../structPLStream.html#a9c2d4f0ec960852d804de07c24ceca4f',1,'PLStream']]],
  ['freetype',['freetype',['../classwxPLDevBase.html#a4b483a1bf1a4cd3ea7c0ad7e81069e6a',1,'wxPLDevBase']]],
  ['ft',['FT',['../structPLStream.html#ae3368cf4ce039d91f955ac2c1c365e8a',1,'PLStream']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_66.js <==
var searchData=
[
  ['f',['f',['../structplplot_1_1__N5.html#a10a493c8a3873541c5631b3699a276e1',1,'plplot::_N5::f()'],['../structplplot_1_1__N6.html#abb808eca634b7eea7801be932a5bcc24',1,'plplot::_N6::f()'],['../structPLfGrid.html#a639c6caea5afe956c4b25a0d83457257',1,'PLfGrid::f()'],['../structPLfGrid2.html#ae0738c2c824c92eacf754fe2c3adc636',1,'PLfGrid2::f()']]],
  ['f2eval',['f2eval',['../structplf2ops__t.html#a13c5ce017876fcde152ba0e9f28f818e',1,'plf2ops_t']]],
  ['faceted',['FACETED',['../classplplot.html#a18562f076d6241fcb70174c56cc9d0f2',1,'plplot::FACETED()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad9704a54d0cce3496ac15f537f6faa77',1,'plplot.core.plplotjavacConstants.FACETED()'],['../namespaceplplotc.html#a06cb014434e1693c91aafa65d2996c52',1,'plplotc.FACETED()']]],
  ['falsecolor',['falsecolor',['../plot3d_8c.html#a35fc920e3be5be1abe62e62b509c7bf8',1,'plot3d.c']]],
  ['famadv',['famadv',['../structPLStream.html#a15b0c38ac1073ccd572752bbca88642a',1,'PLStream']]],
  ['family',['family',['../structTextSizeInfo.html#ae9c7df23906c0fba489e3b10f95173bc',1,'TextSizeInfo::family()'],['../structPLStream.html#a45e944722760a5e71145fcdde5de2988',1,'PLStream::family()']]],
  ['familylookup',['familyLookup',['../cairo_8c.html#ac9fb021905982c9f5c5f1213d0a6fa09',1,'cairo.c']]],
  ['fc_5fmaxz',['fc_maxz',['../plot3d_8c.html#af927db7d342d1f8086233de68aef9122',1,'plot3d.c']]],
  ['fc_5fminz',['fc_minz',['../plot3d_8c.html#ab3ab5bb5121a04bc6d319c8e5d344d0a',1,'plot3d.c']]],
  ['fci',['fci',['../structFCI__to__FontName__Table.html#a10edb24d1c032ee66f3de1be72ce0aa0',1,'FCI_to_FontName_Table::fci()'],['../structPLStream.html#ad5b9970ff24d3eadc87e039312e1e498',1,'PLStream::fci()']]],
  ['fcncoordtrans',['fcnCoordTrans',['../plplot__octaveOCTAVE__wrap_8cxx.html#a155f6008b033b8b13bc7ead36da93c6e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['fcnlabelfunc',['fcnLabelFunc',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9dc9722fd122f685f600c847d96992d4',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['fcnmapform',['fcnMapForm',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab35fb75236326f44a50a302d85f5f72c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['fd',['fd',['../structPLiodev.html#a1ecf4e38fea001587e942564372e1196',1,'PLiodev']]],
  ['fdata',['fdata',['../structtclMatrix.html#a4f4d6a7288dc4f8972e0f708b5eac2ee',1,'tclMatrix']]],
  ['fflen',['fflen',['../structPLStream.html#aa7440a327d3574823524dd545fd47281',1,'PLStream']]],
  ['fgcolor',['fgcolor',['../structTkwDisplay.html#af3d31f2906890adc100c5ada119560e4',1,'TkwDisplay::fgcolor()'],['../structXwDisplay.html#a88fee844ac89cb7046fb8a1dbd79b8a5',1,'XwDisplay::fgcolor()']]],
  ['file',['file',['../structPDFstrm.html#a736196e61b0cdeb3463a200dc39efae6',1,'PDFstrm::file()'],['../structPLiodev.html#a29d807a9caf26fb58320dcc4598e7174',1,'PLiodev::file()']]],
  ['filehandle',['fileHandle',['../structPLiodev.html#a39d8e71193ac0bdf062a381fb945891b',1,'PLiodev']]],
  ['filename',['fileName',['../structPLiodev.html#a3ad87e4e8c43f6d0c9b5d4b3350274ef',1,'PLiodev::fileName()'],['../structPLStream.html#a851b40b7643756cf9e7c998101bf3dfc',1,'PLStream::FileName()'],['../tkMain_8c.html#a1862cb72b37ffe98140c1fcf06a28969',1,'fileName():&#160;tkMain.c']]],
  ['fill',['fill',['../structarc__struct.html#afe157be1d680aa7664b402c7591648e3',1,'arc_struct']]],
  ['finc',['finc',['../structPLStream.html#a052c6ef447de417a9670e6ee0dbfdd57',1,'PLStream']]],
  ['first_5fid',['first_id',['../structdelaunay.html#a9e2372eabc17ab9883c5cf1fdc9698fd',1,'delaunay']]],
  ['flags',['flags',['../structdelaunay.html#af01616b85855dda0358e7f7db76aab4a',1,'delaunay::flags()'],['../structPlFrame.html#ac7d94201e4d78f789f1a70a8c23974e7',1,'PlFrame::flags()'],['../structPlPlotter.html#ad646104e671c52179ff2e95097f86b22',1,'PlPlotter::flags()'],['../structTkwDev.html#a674aac7197570ce479b71cafc94e5fc7',1,'TkwDev::flags()'],['../structswig__octave__member.html#ac4ef5a8526e5efe3966b6cad209b3271',1,'swig_octave_member::flags()']]],
  ['fntbffr',['fntbffr',['../plsym_8c.html#af2b4286fc1004e0b6909e9618ec32728',1,'plsym.c']]],
  ['fntindx',['fntindx',['../plsym_8c.html#a3c4021b9f3a74ea606a02e08e07e976c',1,'plsym.c']]],
  ['fntlkup',['fntlkup',['../plsym_8c.html#a14403991913eddd3ba18b2144c412684',1,'plsym.c']]],
  ['font',['Font',['../structHershey__to__Unicode__table.html#a521461503b5769550a4fa14a9920312b',1,'Hershey_to_Unicode_table']]],
  ['font_5fface',['font_face',['../structEscText.html#acf964bbf4e977b425f33a26da0e1c9c8',1,'EscText']]],
  ['font_5ftypes',['font_types',['../plsym_8c.html#a76b3973fc2f1b1e8214f93bebb3ca837',1,'plsym.c']]],
  ['fontfamilylookup',['fontFamilyLookup',['../wxwidgets_8h.html#a98e63d912a13da0ed2a2568547e55479',1,'wxwidgets.h']]],
  ['fontlist',['fontlist',['../structcdImageStruct.html#aa1f1595229c3fae8971b0f83d38b08b3',1,'cdImageStruct']]],
  ['fontloaded',['fontloaded',['../plsym_8c.html#aaffc055192a40b2b7bda72fff0aba9f6',1,'plsym.c']]],
  ['fontsize',['fontSize',['../structPLCairo.html#a1bd9c88d9f2013801eabf81685c2022e',1,'PLCairo']]],
  ['fontstylelookup',['fontStyleLookup',['../wxwidgets_8h.html#a9527465bcb32eac9a8b9d7f58567e825',1,'wxwidgets.h']]],
  ['fontweightlookup',['fontWeightLookup',['../wxwidgets_8h.html#a9f01825db2b4a454b7c875fe6cd7c385',1,'wxwidgets.h']]],
  ['foo',['foo',['../plcore_8c.html#a819b717d29c6c488a332fefeeb3815ba',1,'foo():&#160;plcore.c'],['../plgradient_8c.html#a819b717d29c6c488a332fefeeb3815ba',1,'foo():&#160;plgradient.c']]],
  ['fp',['fp',['../structPSDev.html#a2218cf8dd6d7fb30f735073048438253',1,'PSDev']]],
  ['free2dgrid',['Free2dGrid',['../classplplot.html#a284542add18e412b4f9f6b071dc6a9b3',1,'plplot']]],
  ['freeaspect',['freeaspect',['../structPLStream.html#a9c2d4f0ec960852d804de07c24ceca4f',1,'PLStream']]],
  ['ft',['FT',['../structPLStream.html#ae3368cf4ce039d91f955ac2c1c365e8a',1,'PLStream']]]
];
